import React__default, { useRef } from 'react';
import { Transition } from 'react-transition-group';
import useWizard from './useWizard.js';
import './WizardTransition.scss.js';

var clearEnter = function clearEnter(el) {
  if (el) {
    el.classList.remove(slideRtlClassNames.enter);
    el.classList.remove(slideLtrClassNames.enter);
    el.classList.remove(slideRtlClassNames.enterActive);
    el.classList.remove(slideLtrClassNames.enterActive);
  }
};

var clearExit = function clearExit(el) {
  if (el) {
    el.classList.remove(slideLtrClassNames.exit);
    el.classList.remove(slideRtlClassNames.exit);
    el.classList.remove(slideLtrClassNames.exitActive);
    el.classList.remove(slideRtlClassNames.exitActive);
  }
};

var WizardTransition = (function (_ref) {
  var renderedStep = _ref.renderedStep,
      renderedIndex = _ref.renderedIndex,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      children = _ref.children,
      style = _ref.style;

  var _useWizard = useWizard(),
      currentStep = _useWizard.currentStep,
      currentStepIndex = _useWizard.currentStepIndex,
      previousStepIndex = _useWizard.previousStepIndex;

  var contentRef = useRef(null);
  var stateRef = useRef({
    enter: false,
    exit: false
  });
  return /*#__PURE__*/React__default.createElement(Transition, {
    nodeRef: contentRef,
    onEnter: function onEnter() {
      if (stateRef.current.exit) {
        clearExit(contentRef.current);
        stateRef.current.exit = false;
      }

      var anim = renderedIndex > previousStepIndex ? slideRtlClassNames : slideLtrClassNames;
      contentRef.current && contentRef.current.classList.add(anim.enter);
      stateRef.current.enter = true;
    },
    onEntering: function onEntering() {
      setTimeout(function () {
        if (!stateRef.current.enter) return;
        var anim = renderedIndex > previousStepIndex ? slideRtlClassNames : slideLtrClassNames;
        contentRef.current && contentRef.current.classList.add(anim.enterActive);
      });
    },
    onEntered: function onEntered() {
      clearEnter(contentRef.current);
      stateRef.current.enter = false;
    },
    onExit: function onExit() {
      if (stateRef.current.enter) {
        clearEnter(contentRef.current);
        stateRef.current.enter = false;
      }

      var anim = renderedIndex > currentStepIndex ? slideRtlClassNames : slideLtrClassNames;
      contentRef.current && contentRef.current.classList.add(anim.exit);
      stateRef.current.exit = true;
    },
    onExiting: function onExiting() {
      if (!stateRef.current.exit) return;
      var anim = renderedIndex > currentStepIndex ? slideRtlClassNames : slideLtrClassNames;
      contentRef.current && contentRef.current.classList.add(anim.exitActive);
    },
    onExited: function onExited() {
      clearExit(contentRef.current);
      stateRef.current.exit = false;
    },
    "in": currentStep === renderedStep,
    unmountOnExit: true,
    appear: renderedIndex !== 0,
    timeout: 400
  }, /*#__PURE__*/React__default.createElement("div", {
    className: className,
    ref: contentRef,
    style: style
  }, children));
});
var slideLtrClassNames = {
  enter: 'Suc-ltr-enter',
  enterActive: 'Suc-ltr-enter-active',
  exit: 'Suc-ltr-exit',
  exitActive: 'Suc-ltr-exit-active'
};
var slideRtlClassNames = {
  enter: 'Suc-rtl-enter',
  enterActive: 'Suc-rtl-enter-active',
  exit: 'Suc-rtl-exit',
  exitActive: 'Suc-rtl-exit-active'
};

export { WizardTransition as default };
//# sourceMappingURL=WizardTransition.js.map
